index.RecordIdentifierIndex

|  | ## Cheshire3 Object Model: Class RecordIdentifierIndex

Module index :: Class RecordIdentifierIndex

## Class RecordIdentifierIndex
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
            baseObjects.Index --+
                                |
                               RecordIdentifierIndex

Instance Methods

begin_indexing(self, session) Perform tasks before indexing any records
commit_indexing(self, session) Perform tasks after records have been indexed
index_record(self, session, record) Accept a record to index.
delete_record(self, session, record) Delete all the terms of the given record from the indexes.
scan(self, session, clause, db) Produce an ordered term list with document frequencies and total occurences
search(self, session, clause, db) Search this particular index given a CQL clause, return a resultSet object
Inherited from `baseObjects.Index`: `construct_item`, `construct_resultSet`, `deserialise_terms`, `merge_terms`, `serialise_terms`, `sort` Inherited from `configParser.C3Object`: `__init__`, `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `baseObjects.Index`: `indexStore` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### begin_indexing(self, session) | source code
Perform tasks before indexing any records Overrides: baseObjects.Index.begin_indexing (inherited documentation)

### commit_indexing(self, session) | source code
Perform tasks after records have been indexed Overrides: baseObjects.Index.commit_indexing (inherited documentation)

### index_record(self, session, record) | source code
Accept a record to index. If begin indexing has been called, the index might not commit any data until commit_indexing is called. If it is not in batch mode, then index_record will also commit the terms to the indexStore. Overrides: baseObjects.Index.index_record (inherited documentation)

### delete_record(self, session, record) | source code
Delete all the terms of the given record from the indexes. Does this by extracting the terms from the record, finding and removing them. Hence the record must be the same as the one that was indexed. Overrides: baseObjects.Index.delete_record (inherited documentation)

### scan(self, session, clause, db) | source code
Produce an ordered term list with document frequencies and total occurences Overrides: baseObjects.Index.scan (inherited documentation)

### search(self, session, clause, db) | source code
Search this particular index given a CQL clause, return a resultSet object Overrides: baseObjects.Index.search (inherited documentation)